@@ -1,7 +1,7 @@
 """ECO ID to Evidence code group dictionary from evidenceontology"""
 
 # pylint: disable=too-many-lines
-# 1117 ECO IDs
+# 1239 ECO IDs
 ECO2GRP = {
     'ECO:0000030': 'ISA',
     'ECO:0000031': 'ISA',
@@ -39,8 +39,7 @@ ECO2GRP = {
     'ECO:0000276': 'IEP',
     'ECO:0000277': 'IEP',
     'ECO:0000278': 'EXP',
-    'ECO:0000279': 'IDA',
-    'ECO:0000280': 'IEP',
+    'ECO:0000279': 'IEP',
     'ECO:0000281': 'IEP',
     'ECO:0000282': 'IEP',
     'ECO:0000283': 'IEP',
@@ -63,7 +62,7 @@ ECO2GRP = {
     'ECO:0000317': 'IGC',
     'ECO:0000318': 'IBA',
     'ECO:0000319': 'IBD',
-    'ECO:0000320': 'IMR',
+    'ECO:0000320': 'IKR',
     'ECO:0000321': 'IRD',
     'ECO:0000322': 'IEA',
     'ECO:0000323': 'IEA',
@@ -168,7 +167,6 @@ ECO2GRP = {
     'ECO:0001220': 'IDA',
     'ECO:0001221': 'IDA',
     'ECO:0001222': 'IDA',
-    'ECO:0001223': 'IMP',
     'ECO:0001224': 'IMP',
     'ECO:0001225': 'IMP',
     'ECO:0001226': 'IPI',
@@ -230,13 +228,30 @@ ECO2GRP = {
     'ECO:0001579': 'IDA',
     'ECO:0001581': 'IEA',
     'ECO:0001582': 'EXP',
-    'ECO:0001807': 'IDA',
+    'ECO:0001584': 'IEA',
+    'ECO:0001585': 'IMP',
+    'ECO:0001587': 'IEA',
+    'ECO:0001588': 'EXP',
+    'ECO:0001593': 'IEA',
+    'ECO:0001594': 'EXP',
+    'ECO:0001599': 'IEA',
+    'ECO:0001600': 'EXP',
+    'ECO:0001807': 'IPI',
     'ECO:0001808': 'EXP',
-    'ECO:0001828': 'IC',
+    'ECO:0001831': 'IEA',
+    'ECO:0001832': 'EXP',
+    'ECO:0001834': 'IEA',
+    'ECO:0001835': 'EXP',
+    'ECO:0001837': 'IEA',
+    'ECO:0001838': 'IEP',
+    'ECO:0001840': 'IEA',
+    'ECO:0001841': 'IEP',
+    'ECO:0001843': 'IEA',
+    'ECO:0001844': 'IMP',
     'ECO:0005501': 'IDA',
     'ECO:0005523': 'EXP',
     'ECO:0005527': 'EXP',
-    'ECO:0005530': 'EXP',
+    'ECO:0005530': 'IMP',
     'ECO:0005556': 'ISA',
     'ECO:0005557': 'IEA',
     'ECO:0005558': 'ISA',
@@ -253,8 +268,6 @@ ECO2GRP = {
     'ECO:0005595': 'IDA',
     'ECO:0005597': 'IDA',
     'ECO:0005601': 'IDA',
-    'ECO:0005611': 'IDA',
-    'ECO:0005612': 'IMP',
     'ECO:0005613': 'EXP',
     'ECO:0005614': 'IDA',
     'ECO:0005615': 'IEP',
@@ -330,6 +343,7 @@ ECO2GRP = {
     'ECO:0006011': 'IPI',
     'ECO:0006013': 'IDA',
     'ECO:0006015': 'IDA',
+    'ECO:0006017': 'TAS',
     'ECO:0006019': 'IC',
     'ECO:0006021': 'IDA',
     'ECO:0006023': 'IDA',
@@ -358,7 +372,7 @@ ECO2GRP = {
     'ECO:0006060': 'IEA',
     'ECO:0006061': 'IDA',
     'ECO:0006062': 'IDA',
-    'ECO:0006063': 'EXP',
+    'ECO:0006063': 'IMP',
     'ECO:0006064': 'IDA',
     'ECO:0006067': 'IDA',
     'ECO:0006068': 'IEP',
@@ -391,6 +405,118 @@ ECO2GRP = {
     'ECO:0006097': 'IGI',
     'ECO:0006099': 'IMP',
     'ECO:0006101': 'IMP',
+    'ECO:0006156': 'IEA',
+    'ECO:0006158': 'IEA',
+    'ECO:0006160': 'IEA',
+    'ECO:0006162': 'IEA',
+    'ECO:0006164': 'IEA',
+    'ECO:0006165': 'EXP',
+    'ECO:0006167': 'IEA',
+    'ECO:0006168': 'EXP',
+    'ECO:0006170': 'IEP',
+    'ECO:0006171': 'IEA',
+    'ECO:0006173': 'IEA',
+    'ECO:0006174': 'IEP',
+    'ECO:0006196': 'EXP',
+    'ECO:0006197': 'IEA',
+    'ECO:0006198': 'EXP',
+    'ECO:0006199': 'IEA',
+    'ECO:0006200': 'EXP',
+    'ECO:0006201': 'IEA',
+    'ECO:0006202': 'EXP',
+    'ECO:0006203': 'IEA',
+    'ECO:0006204': 'EXP',
+    'ECO:0006205': 'IEA',
+    'ECO:0006206': 'EXP',
+    'ECO:0006207': 'IEA',
+    'ECO:0006208': 'IDA',
+    'ECO:0006209': 'IEA',
+    'ECO:0006210': 'EXP',
+    'ECO:0006211': 'IEA',
+    'ECO:0006212': 'EXP',
+    'ECO:0006213': 'IEA',
+    'ECO:0006214': 'EXP',
+    'ECO:0006215': 'IEA',
+    'ECO:0006217': 'IEA',
+    'ECO:0006219': 'IEA',
+    'ECO:0006220': 'EXP',
+    'ECO:0006221': 'IEA',
+    'ECO:0006222': 'EXP',
+    'ECO:0006223': 'IEA',
+    'ECO:0006224': 'IDA',
+    'ECO:0006225': 'IEA',
+    'ECO:0006226': 'IDA',
+    'ECO:0006227': 'IEA',
+    'ECO:0006228': 'EXP',
+    'ECO:0006229': 'IEA',
+    'ECO:0006230': 'IDA',
+    'ECO:0006231': 'IEA',
+    'ECO:0006232': 'IDA',
+    'ECO:0006233': 'IEA',
+    'ECO:0006234': 'IDA',
+    'ECO:0006235': 'IEA',
+    'ECO:0006236': 'EXP',
+    'ECO:0006237': 'IEA',
+    'ECO:0006241': 'IEP',
+    'ECO:0006242': 'IEA',
+    'ECO:0006243': 'IEP',
+    'ECO:0006244': 'IEA',
+    'ECO:0006245': 'EXP',
+    'ECO:0006246': 'IEA',
+    'ECO:0006275': 'EXP',
+    'ECO:0006276': 'IEA',
+    'ECO:0006277': 'IPI',
+    'ECO:0006278': 'IEA',
+    'ECO:0006281': 'IDA',
+    'ECO:0006282': 'IEA',
+    'ECO:0006283': 'EXP',
+    'ECO:0006284': 'IEA',
+    'ECO:0006285': 'EXP',
+    'ECO:0006286': 'IEA',
+    'ECO:0006287': 'EXP',
+    'ECO:0006288': 'IEA',
+    'ECO:0006289': 'EXP',
+    'ECO:0006290': 'IEA',
+    'ECO:0006291': 'IDA',
+    'ECO:0006292': 'IEA',
+    'ECO:0006293': 'IPI',
+    'ECO:0006294': 'IEA',
+    'ECO:0006295': 'IPI',
+    'ECO:0006296': 'IEA',
+    'ECO:0006297': 'IPI',
+    'ECO:0006298': 'IEA',
+    'ECO:0006299': 'EXP',
+    'ECO:0006300': 'IEA',
+    'ECO:0006301': 'IDA',
+    'ECO:0006302': 'IEA',
+    'ECO:0006303': 'IPI',
+    'ECO:0006304': 'IEA',
+    'ECO:0006305': 'IDA',
+    'ECO:0006306': 'IEA',
+    'ECO:0006307': 'IDA',
+    'ECO:0006308': 'IEA',
+    'ECO:0006309': 'IPI',
+    'ECO:0006310': 'IEA',
+    'ECO:0006311': 'EXP',
+    'ECO:0006312': 'IEA',
+    'ECO:0006313': 'EXP',
+    'ECO:0006314': 'IEA',
+    'ECO:0006315': 'EXP',
+    'ECO:0006316': 'IEA',
+    'ECO:0006317': 'EXP',
+    'ECO:0006318': 'IEA',
+    'ECO:0006319': 'IDA',
+    'ECO:0006320': 'IEA',
+    'ECO:0006321': 'IPI',
+    'ECO:0006322': 'IEA',
+    'ECO:0006323': 'IDA',
+    'ECO:0006324': 'IEA',
+    'ECO:0006325': 'IDA',
+    'ECO:0006326': 'IEA',
+    'ECO:0006327': 'IPI',
+    'ECO:0006328': 'IEA',
+    'ECO:0006329': 'IPI',
+    'ECO:0006330': 'IEA',
     'ECO:0007001': 'HMP',
     'ECO:0007003': 'HGI',
     'ECO:0007005': 'HDA',
@@ -513,14 +639,11 @@ ECO2GRP = {
     'ECO:0007180': 'IDA',
     'ECO:0007181': 'IDA',
     'ECO:0007182': 'IDA',
-    'ECO:0007183': 'IEP',
     'ECO:0007184': 'EXP',
     'ECO:0007185': 'IDA',
     'ECO:0007186': 'IDA',
     'ECO:0007187': 'IDA',
     'ECO:0007188': 'IDA',
-    'ECO:0007189': 'IDA',
-    'ECO:0007190': 'IMP',
     'ECO:0007191': 'EXP',
     'ECO:0007192': 'IDA',
     'ECO:0007193': 'IEA',
@@ -610,14 +733,11 @@ ECO2GRP = {
     'ECO:0007284': 'IEA',
     'ECO:0007285': 'IEA',
     'ECO:0007286': 'IEA',
-    'ECO:0007287': 'IEA',
     'ECO:0007288': 'IEA',
     'ECO:0007289': 'IEA',
     'ECO:0007290': 'IEA',
     'ECO:0007291': 'IEA',
     'ECO:0007292': 'IEA',
-    'ECO:0007293': 'IEA',
-    'ECO:0007294': 'IMP',
     'ECO:0007295': 'IEA',
     'ECO:0007296': 'IEA',
     'ECO:0007297': 'IEA',
@@ -631,7 +751,6 @@ ECO2GRP = {
     'ECO:0007305': 'IEA',
     'ECO:0007306': 'IEA',
     'ECO:0007307': 'IEA',
-    'ECO:0007308': 'IEA',
     'ECO:0007309': 'IEA',
     'ECO:0007310': 'IEA',
     'ECO:0007311': 'IEA',
@@ -749,7 +868,6 @@ ECO2GRP = {
     'ECO:0007423': 'IEA',
     'ECO:0007424': 'IEA',
     'ECO:0007425': 'IEA',
-    'ECO:0007426': 'IEA',
     'ECO:0007427': 'IEA',
     'ECO:0007428': 'IEA',
     'ECO:0007429': 'IEA',
@@ -1120,4 +1238,8 @@ ECO2GRP = {
     'ECO:0007841': 'IEA',
     'ECO:0007842': 'IEA',
     'ECO:0007843': 'IEA',
+    'ECO:0007845': 'IEA',
+    'ECO:0007846': 'IDA',
+    'ECO:0007848': 'IEA',
+    'ECO:0007849': 'IDA',
 }
